/**
 * This program demonstrates how to utilize the dual-core capabilities of the 
 * Raspberry Pi Pico using the C/C++ SDK. By leveraging both cores, we can 
 * achieve parallel processing, allowing for more efficient and performant 
 * applications. In this example, we control two LEDs concurrently, with core0 
 * handling one LED and core1 handling the other. This approach highlights the 
 * potential for task distribution across the two cores, showcasing the 
 * advanced capabilities of the RP2040 microcontroller.
 * 
 * Goals:
 * - Core0 (the main core) handles the LED connected to pin 1, which blinks on 
 *   and off with a pattern of 50 milliseconds on and 2500 milliseconds off.
 * - Core1 (the secondary core) controls the LED connected to pin 5, adjusting 
 *   its brightness in a fade in-fade out pattern using pulse-width modulation 
 *   (PWM) with variable brightness levels.
 * 
 * Hardware Requirements:
 * - Raspberry Pi Pico
 * - Two LEDs connected to pin 1 and pin 5
 * - Resistors suitable for the LEDs
 * - Connection wires
 * 
 * Tested with Arduino IDE v1.8.19 and Arduino Mbed OS RP2040 boards v4.1.1.
 */

#include <Arduino.h>
#include "pico/multicore.h"

#define CORE0_LED 1u
#define CORE1_LED 5u
int brightness = 0;
int fadevalue = 10;

void core1_loop() {
  while (1)
  {
    brightness = brightness + fadevalue;
    if (brightness <= 0 || brightness >= 2048) {
      fadevalue = -fadevalue;
    }
    digitalWrite(CORE1_LED, HIGH);
    sleep_us(brightness);
    digitalWrite(CORE1_LED, LOW);
    sleep_us(2000);
  }
}

void setup()
{
  pinMode(CORE1_LED, OUTPUT);
  pinMode(CORE0_LED, OUTPUT);
  delay(1000);  // Enélkül Core1 leállhat!
  //multicore_reset_core1();
  multicore_launch_core1(core1_loop);
}

void loop() {
  digitalWrite(CORE0_LED, HIGH);
  delay(50);
  digitalWrite(CORE0_LED, LOW);
  delay(2500);
}
